gdaniels 2002/11/01 09:39:24
Modified: java/src/org/apache/axis/encoding
TypeMappingRegistryImpl.java
TypeMappingRegistry.java
java/test/encoding TestBeanDeser2.java
java/src/org/apache/axis/message RPCElement.java
Log:
A little cleanup of imports, etc.
Change namespaceURI -> encodingStyle to match JAX-RPC API
Revision Changes Path
1.20 +8 -8
xml-axis/java/src/org/apache/axis/encoding/TypeMappingRegistryImpl.java
Index: TestBeanDeser2.java
===================================================================
RCS file: /home/cvs/xml-axis/java/test/encoding/TestBeanDeser2.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- TestBeanDeser2.java 19 Sep 2002 20:25:12 -0000 1.2
+++ TestBeanDeser2.java 1 Nov 2002 17:39:24 -0000 1.3
@@ -10,14 +10,8 @@
import org.apache.axis.message.RPCParam;
import org.apache.axis.message.SOAPEnvelope;
import org.apache.axis.server.AxisServer;
-import org.apache.axis.utils.JavaUtils;
import javax.xml.namespace.QName;
-import java.lang.reflect.Array;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
import java.util.Vector;
/**
@@ -30,11 +24,6 @@
private AxisServer server = new AxisServer();
public TestBeanDeser2(String name) {
- this(name, Constants.URI_DEFAULT_SCHEMA_XSI,
- Constants.URI_DEFAULT_SCHEMA_XSD);
- }
-
- public TestBeanDeser2(String name, String NS_XSI, String NS_XSD) {
super(name);
header =
"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
1.78 +1 -2 xml-axis/java/src/org/apache/axis/message/RPCElement.java
Index: RPCElement.java
===================================================================
RCS file: /home/cvs/xml-axis/java/src/org/apache/axis/message/RPCElement.java,v
retrieving revision 1.77
retrieving revision 1.78
diff -u -r1.77 -r1.78
--- RPCElement.java 9 Oct 2002 19:06:31 -0000 1.77
+++ RPCElement.java 1 Nov 2002 17:39:24 -0000 1.78
@@ -374,11 +374,10 @@
/**
* needHeaderProcessing
- * @param opereration OperationDesc
+ * @param operation OperationDesc
* @param isResponse boolean indicates if request or response message
* @param context DeserializationContext
* @param handler RPCHandler used to deserialize parameters
- * @return true if the operation description indicates parameters/results
* are located in the soap header.
*/
private void processHeaders(OperationDesc operation,
Index: TypeMappingRegistryImpl.java
===================================================================
RCS file:
/home/cvs/xml-axis/java/src/org/apache/axis/encoding/TypeMappingRegistryImpl.java,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- TypeMappingRegistryImpl.java 18 Oct 2002 20:54:28 -0000 1.19
+++ TypeMappingRegistryImpl.java 1 Nov 2002 17:39:24 -0000 1.20
@@ -315,23 +315,23 @@
}
/**
* Obtain a type mapping for the given namespaceURI. If no specific
* mapping exists for this namespaceURI, we will create and register
* one before returning it.
*
* @param namespaceURI
* @return a registered TypeMapping for the given namespaceURI
*/
- public TypeMapping getOrMakeTypeMapping(String namespaceURI) {
- TypeMapping del = (TypeMapping) mapTM.get(namespaceURI);
+ public TypeMapping getOrMakeTypeMapping(String encodingStyle) {
+ TypeMapping del = (TypeMapping) mapTM.get(encodingStyle);
TypeMapping tm = null;
if (del != null) {
tm = del.getDelegate();
}
if (tm == null) {
tm = (TypeMapping)createTypeMapping();
- tm.setSupportedEncodings(new String[] {namespaceURI});
- register(namespaceURI, tm);
+ tm.setSupportedEncodings(new String[] {encodingStyle});
+ register(encodingStyle, tm);
}
return tm;
}
@@ -315,23 +315,23 @@
}
/**
- * Obtain a type mapping for the given namespaceURI. If no specific
- * mapping exists for this namespaceURI, we will create and register
+ * Obtain a type mapping for the given encodingStyle. If no specific
+ * mapping exists for this encodingStyle, we will create and register
* one before returning it.
*
@@ -315,23 +315,23 @@
* one before returning it.
*
- * @param namespaceURI
- * @return a registered TypeMapping for the given namespaceURI
+ * @param encodingStyle
+ * @return a registered TypeMapping for the given encodingStyle
*/
1.52 +5 -5
xml-axis/java/src/org/apache/axis/encoding/TypeMappingRegistry.java
Index: TypeMappingRegistry.java
===================================================================
RCS file:
/home/cvs/xml-axis/java/src/org/apache/axis/encoding/TypeMappingRegistry.java,v
retrieving revision 1.51
retrieving revision 1.52
diff -u -r1.51 -r1.52
--- TypeMappingRegistry.java 17 Oct 2002 04:40:19 -0000 1.51
+++ TypeMappingRegistry.java 1 Nov 2002 17:39:24 -0000 1.52
@@ -70,14 +70,14 @@
public void delegate(TypeMappingRegistry secondaryTMR);
/**
* Obtain a type mapping for the given namespaceURI. If no specific
* mapping exists for this namespaceURI, we will create and register
* one before returning it.
*
* @param namespaceURI
* @return a registered TypeMapping for the given namespaceURI
*/
- public TypeMapping getOrMakeTypeMapping(String namespaceURI);
+ public TypeMapping getOrMakeTypeMapping(String encodingStyle);
}
1.3 +0 -11 xml-axis/java/test/encoding/TestBeanDeser2.java
@@ -70,14 +70,14 @@
public void delegate(TypeMappingRegistry secondaryTMR);
/**
- * Obtain a type mapping for the given namespaceURI. If no specific
- * mapping exists for this namespaceURI, we will create and register
+ * Obtain a type mapping for the given encoding style. If no specific
+ * mapping exists for this encoding style, we will create and register
* one before returning it.
*
@@ -70,14 +70,14 @@
* one before returning it.
*
- * @param namespaceURI
- * @return a registered TypeMapping for the given namespaceURI
+ * @param encodingStyle
+ * @return a registered TypeMapping for the given encoding style
*/